# CHANGELOG

## 0.1.2

Date: 2018-11-15

- Change:
  - Process worker mode by default
  - Dynamic workers count by default
- Add:
  - `--workers-type` argument

## 0.1.1

Date: 2018-11-14

- Change:
  - Rename argument `--log-conf` to `--logging-config`
- Add:
  - `--num-threads` argument
- Modify:
  - Add `version` module.

And many other modifications.

## 0.1.0

Date: 2018-11-07

A very early experimental release
